@@ -1,19 +1,19 @@
 from typing import Optional
-from ormlambda.caster import BaseCaster, PLACEHOLDER
+from ormlambda.caster import BaseCaster, Caster
 
 
 class BytesCaster[TType](BaseCaster[bytes, TType]):
     def __init__(self, value: bytes, type_value: TType):
         super().__init__(value, type_value)
 
-    def wildcard_to_select(self, value: str = PLACEHOLDER) -> str:
-        return value
+    def wildcard_to_select(self, value: Optional[str] = None) -> str:
+        return Caster.PLACEHOLDER if value is None else value
 
-    def wildcard_to_where(self, value: str = PLACEHOLDER) -> str:
-        return value
+    def wildcard_to_where(self, value: Optional[str] = None) -> str:
+        return Caster.PLACEHOLDER if value is None else value
 
-    def wildcard_to_insert(self, value: str = PLACEHOLDER) -> str:
-        return value
+    def wildcard_to_insert(self, value: Optional[str] = None) -> str:
+        return Caster.PLACEHOLDER if value is None else value
 
     @property
     @BaseCaster.return_value_if_exists
