@@ -6,6 +6,7 @@ from ormlambda.sql import Column
 from ormlambda.sql import ForeignKey
 from ormlambda.util.module_tree.dfs_traversal import DFSTraversal
 from ormlambda.sql.ddl import CreateTable
+from ormlambda.util import make_hashable 
 
 if TYPE_CHECKING:
     from ormlambda.statements import BaseStatement
@@ -95,7 +96,8 @@ class Table(metaclass=TableMeta):
     def to_dict(self) -> dict[str, str | int]:
         dicc: dict[str, Any] = {}
         for x in self.__annotations__:
-            dicc[x] = getattr(self, x)
+            value = getattr(self, x)
+            dicc[x] = make_hashable(value)
         return dicc
 
     @classmethod
