@@ -20,6 +20,8 @@ type UnionType = tp.Literal["AND", "OR", ""]
 type ComparerTypes = ComparerType | UnionType | ConditionEnum
 # endregion
 
-type TupleJoinType[T] = tuple[Comparer[T], JoinType]
+type TupleJoinType[T] = tuple[Comparer]
 
 ASTERISK: AsteriskType = "*"
+
+from .compiler import *
